diff --git a/hammer.c b/hammer.c
index cd630a69a491c1ec6eeb8f13adbc3c02962bcac9..b8d0afc114851b8a97c5999b279a985fe126e6ad 100644
--- a/hammer.c
+++ b/hammer.c
@@ -29,12 +29,12 @@ const gchar* to_string(parse_state *ps) {
   return g_strescape(ps->input, NULL);
 }
 
-const result* get_cached(parse_state *ps, const size_t pid); /* {
+const parse_result* get_cached(parse_state *ps, const size_t pid); /* {
   gpointer p = g_hash_table_lookup(ps->cache, &pid);
   if (NULL != p)
 }
 							     */
-int put_cached(parse_state *ps, const size_t pid, result cached);
+int put_cached(parse_state *ps, const size_t pid, parse_result cached);
 
 parser *token(const uint8_t *s) { return NULL; }
 parser *ch(const uint8_t c) { return NULL; }
diff --git a/hammer.h b/hammer.h
index 67d120d31af9b41b7a4740b69f77d4a685afa660..7c6638a3a8d80677b6ed13415e5e0f655b509689 100644
--- a/hammer.h
+++ b/hammer.h
@@ -8,8 +8,8 @@
  *   index - current position in input
  *   length - size of input
  * THE FOLLOWING DESCRIBES HOW JSPARSE DOES IT. OUR MILEAGE MAY VARY.
  *   cache - a hash table describing the state of the parse, including partial parse
  *           results. It's actually a hash table of [parser_id, hash_table[index, result]],
  *           where the parser id is incremented as the parse goes along (parsers that have
  *           already been applied once don't get a new parser_id ... but the global variable
  *           still increments? not sure why that is, need to debug some), and the locations
@@ -27,9 +27,9 @@ typedef struct {
   const uint8_t *remaining;
   const uint8_t *matched;
   const GSequence *ast;
-} result;
+} parse_result;
 
-typedef result*(*parser)(parse_state*);
+typedef parse_result*(*parser)(parse_state*);
 
 parser *token(const uint8_t *s);
 parser *ch(const uint8_t c);
@@ -8,8 +8,8 @@
  *   length - size of input
  * THE FOLLOWING DESCRIBES HOW JSPARSE DOES IT. OUR MILEAGE MAY VARY.
- *   cache - a hash table describing the state of the parse, including partial parse
- *           results. It's actually a hash table of [parser_id, hash_table[index, result]],
+ *   cache - a hash table describing the state of the parse, including partial parse_results. 
+ *           It's actually a hash table of [parser_id, hash_table[index, parse_result]],
  *           where the parser id is incremented as the parse goes along (parsers that have
  *           already been applied once don't get a new parser_id ... but the global variable